//
//  FabServiceProtocol.h
//  FabService
//
//  Created by Breck H. Auten on 8/24/16.
//  Copyright © 2016 Markzware. All rights reserved.
//

#import <cocoa/cocoa.h>
#import <foundation/NSDictionary.h>
#import <foundation/NSString.h>
#import <foundation/NSArray.h>

// Crashlytics have defined these so that if we use a new SDK then build then we get errors. We'll define these macros to remove any typed collections.

//#ifdef CLS_GENERIC_NSARRAY
#undef CLS_GENERIC_NSARRAY
#define CLS_GENERIC_NSARRAY(type) NSArray
//#endif

//#ifdef CLS_GENERIC_NSDICTIONARY
#undef CLS_GENERIC_NSDICTIONARY
#define CLS_GENERIC_NSDICTIONARY(key_type,object_key) NSDictionary
//#endif

//#ifdef ANS_GENERIC_NSARRAY
#undef ANS_GENERIC_NSARRAY
#define ANS_GENERIC_NSARRAY(type) NSArray
//#endif

//#ifdef ANS_GENERIC_NSDICTIONARY
#undef ANS_GENERIC_NSDICTIONARY
#define ANS_GENERIC_NSDICTIONARY(key_type,object_key) NSDictionary
//#endif

// The protocol that this service will vend as its API. This header file will also need to be visible to the process hosting the service.
@protocol SERVICE_PROTOCOL

- (void)startWithAPIKey:(NSString *)theKey;
- (void)setUserIdentifier:(NSString *)theUserID;
- (void)setUserName:(NSString *)theExtra;
- (void)logLoginWithMethod:(NSString *)theMethod success:(NSNumber*)theSuccess customAttributes:(ANS_GENERIC_NSDICTIONARY (NSString *, id)*)theAttributes;
- (void)logCustomEventWithName:(NSString *)theEventName customAttributes:(ANS_GENERIC_NSDICTIONARY (NSString *, id)*)theAttributes;
    
@end

/*
 To use the service from an application or other process, use NSXPCConnection to establish a connection to the service by doing something like this:

     _connectionToService = [[NSXPCConnection alloc] initWithServiceName:@"com.markzware.FabService"];
     _connectionToService.remoteObjectInterface = [NSXPCInterface interfaceWithProtocol:@protocol(StringModifing)];
     [_connectionToService resume];

Once you have a connection to the service, you can use it like this:

     [[_connectionToService remoteObjectProxy] upperCaseString:@"hello" withReply:^(NSString *aString) {
         // We have received a response. Update our text field, but do it on the main thread.
         NSLog(@"Result string was: %@", aString);
     }];

 And, when you are finished with the service, clean up the connection like this:

     [_connectionToService invalidate];
*/
